# comment out if not nightly snapshot from
# http://viewvc.org/nightly/
%global nightly	20200516

# rel for bumping
%global rel	3

Name:           viewvc
Version:        1.3.0
Release:        %mkrel %{?nightly:0.dev%nightly.}%{rel}
Summary:        Browser interface for CVS and Subversion version control repositories
License:        BSD
Group:          System/Servers
URL:            https://www.viewvc.org/
Source0:        https://viewvc.org%{!?nightly:/downloads}%{?nightly:/nightly}/viewvc-%{version}%{?nightly:-dev-%nightly}.tar.gz
Patch0:         viewvc-tools.patch
Patch1:         viewvc-1.1.14-fhs.patch
Patch2:         CVE-2023-22464.patch
Patch3:         CVE-2023-22456.patch
BuildArch:      noarch
BuildRequires:  python3
Requires:       apache
Requires:       python3
Requires(post): rpm-helper
Requires(postun): rpm-helper
Recommends:     python3-svn
Recommends:     python3-pygments
Recommends:     python3-chardet

%description
ViewVC is a browser interface for CVS and Subversion version control
repositories. It generates templatized HTML to present navigable
directory, revision, and change log listings. It can display specific
versions of files as well as diffs between those versions. Basically,
ViewVC provides the bulk of the report-like functionality you expect out
of your version control tool, but much more prettily than the average
textual command-line program output.

Here are some of the additional features of ViewVC:

    * Support for filesystem-accessible CVS and Subversion repositories.
    * Individually configurable virtual host support.
    * Line-based annotation/blame display (CVS only).
    * Revision graph capabilities (via integration with CvsGraph) (CVS
      only).
    * Syntax highlighting support (via integration with GNU enscript).
    * Bonsai-like repository query facilities.
    * Template-driven output generation.
    * Colorized, side-by-side differences.
    * Tarball generation (by tag/branch for CVS, by revision for
      Subversion).
    * I18N support based on the Accept-Language request header.
    * Ability to run either as CGI script or as a standalone server.
    * Regexp-based file searching.
    * INI-like configuration file (as opposed to requiring actual code
      tweaks).

%prep
%setup -qn %{name}-%{version}%{?nightly:-dev-%nightly}
%autopatch -p1

%build
#nothing

%install
%{__python3} ./viewvc-install --destdir=%{buildroot} --prefix=%{_datadir}/%{name}

# remove uneeded files
rm -rf %{buildroot}%{_datadir}/%{name}/bin/mod_python/.htaccess

# fix python shebangs
%py_shebang_fix %{buildroot}%{_datadir}/%{name}

# fix conf pathname
perl -pi \
        -e 's|CONF_PATHNAME =.*|CONF_PATHNAME = r"%{_sysconfdir}/%{name}/viewvc.conf"|g;' \
        $(find %{buildroot}%{_datadir}/%{name} -type f)

# fix paths in configuration
perl -pi \
  -e 's|^#template_dir = .*|template_dir = %{_datadir}/%{name}/templates/default|g;' \
  -e 's|^#docroot = .*|docroot = /%{name}/static|;' \
  -e 's|^#cvsgraph_conf = .*|cvsgraph_conf = %{_sysconfdir}/%{name}/cvsgraph.conf|;' \
  -e 's|^#mime_types_files = .*|mime_types_files = %{_sysconfdir}/%{name}/mimetypes.conf, %{_sysconfdir}/httpd/conf/mime.types|;' \
  %{buildroot}%{_datadir}/%{name}/viewvc.conf

# install config to sysconf directory
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
install -p -m 644 %{buildroot}%{_datadir}/%{name}/viewvc.conf %{buildroot}%{_sysconfdir}/%{name}/viewvc.conf
rm -rf %{buildroot}%{_datadir}/%{name}/viewvc.conf
install -p -m 644 %{buildroot}%{_datadir}/%{name}/cvsgraph.conf %{buildroot}%{_sysconfdir}/%{name}/cvsgraph.conf
rm -rf %{buildroot}%{_datadir}/%{name}/cvsgraph.conf
install -p -m 644 %{buildroot}%{_datadir}/%{name}/mimetypes.conf %{buildroot}%{_sysconfdir}/%{name}/mimetypes.conf
rm -rf %{buildroot}%{_datadir}/%{name}/mimetypes.conf

# compile the python files
find %{buildroot}%{_datadir}/%{name}/lib -type f -name "*.pyc" -delete

# apache configuration
mkdir -p %{buildroot}%{_webappconfdir}
cat > %{buildroot}%{_webappconfdir}/%{name}.conf <<EOF
# %{name} configuration

Alias /%{name}/static %{_datadir}/%{name}/templates/docroot

<Directory %{_datadir}/%{name}/templates/docroot>
    Require local granted
    ErrorDocument 403 "Access denied per %{_webappconfdir}/%{name}.conf"
</Directory>

Alias /%{name} %{_datadir}/%{name}/bin/cgi

<Directory %{_datadir}/%{name}/bin/cgi>
    Require local granted
    ErrorDocument 403 "Access denied per %{_webappconfdir}/%{name}.conf"
    DirectoryIndex viewvc.cgi
</Directory>
EOF

# set mode 755 on executable scripts
grep -rl '^#!' %{buildroot}%{_datadir}/%{name} | %{_bindir}/xargs %{__chmod} 755

cat >README.mga <<EOF
Mageia RPM specific notes
=========================

Setup
-----
The setup used here differs from default one in order to achieve better FHS
compliance:

- the configuration file is located at /etc/viewvc/viewvc.conf
- the other files are in /usr/share/viewvc

Post-installation
-----------------
You have manually to create the MySQL database if you want to use query mode.

Additional useful packages
--------------------------
- cvs and rcs provide a web interface for CVS repositories
- python3-svn provides a web interface for SVN repositories
- MySQL-python and a MySQL database are needed for query mode
- apache-mod_python, will be accessible at http://localhost/viewvc-mp (instead
  of the cgi files)
EOF

%files
%license LICENSE
%doc CHANGES COMMITTERS INSTALL README.md README.mga docs/
%config(noreplace) %{_sysconfdir}/%{name}
%config(noreplace) %{_webappconfdir}/%{name}.conf
%{_datadir}/%{name}/


%changelog
* Fri May 31 2024 ns80 <ns80> 1.3.0-0.dev20200516.3.mga10
+ Revision: 2068868
- use new macro py_shebang_fix

* Wed Jan 18 2023 ns80 <ns80> 1.3.0-0.dev20200516.2.mga9
+ Revision: 1934272
- port patches from Debian for CVE-2023-22456 and CVE-2023-22464 (mga#31417)

* Sat May 16 2020 wally <wally> 1.3.0-0.dev20200516.1.mga9
+ Revision: 1584739
- update to latest 1.3.0 nightly for python3 support
- recommend python3-pygments and python3-chardet
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Wed Sep 19 2018 umeabot <umeabot> 0:1.1.26-2.mga7
+ Revision: 1276954
- Mageia 7 Mass Rebuild

* Sat Feb 11 2017 zezinho <zezinho> 0:1.1.26-1.mga6
+ Revision: 1085778
- new version 1.1.26 fixing security bug MGA #20262

* Fri Nov 11 2016 luigiwalser <luigiwalser> 0:1.1.25-1.mga6
+ Revision: 1066603
- 1.1.25

* Sat Dec 26 2015 luigiwalser <luigiwalser> 0:1.1.24-1.mga6
+ Revision: 915448
- 1.1.24

* Wed Oct 15 2014 umeabot <umeabot> 0:1.1.22-2.mga5
+ Revision: 739960
- Second Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Fri Feb 14 2014 luigiwalser <luigiwalser> 0:1.1.22-1.mga5
+ Revision: 591009
- 1.1.22

* Sat Sep 14 2013 luigiwalser <luigiwalser> 0:1.1.21-1.mga4
+ Revision: 478877
- 1.1.21

* Sat May 25 2013 shlomif <shlomif> 0:1.1.20-1.mga4
+ Revision: 427535
- New version 1.1.20
+ dmorgan <dmorgan>
- Make rpm rpm compatible with apache2 ( needed for our servers)

* Mon Jan 14 2013 umeabot <umeabot> 0:1.1.17-2.mga3
+ Revision: 385412
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Oct 25 2012 guillomovitch <guillomovitch> 0:1.1.17-1.mga3
+ Revision: 310105
- new version

* Wed Oct 24 2012 luigiwalser <luigiwalser> 0:1.1.15-3.mga3
+ Revision: 309707
- add patch from fedora to fix CVE-2012-4533

* Sat Sep 08 2012 guillomovitch <guillomovitch> 0:1.1.15-2.mga3
+ Revision: 290475
- make webapp configuration file compatible with apache 2.4
- drop mod_python support in webapp configuration file, it doesn't exist anymure

* Wed Jul 04 2012 dams <dams> 0:1.1.15-1.mga3
+ Revision: 267711
- new version 1.1.15

* Wed Jun 13 2012 guillomovitch <guillomovitch> 0:1.1.14-1.mga3
+ Revision: 260277
- FHS compliance: move everything under %%{_datadir}/name
- default configuration now offers consistent access, wether mod_python is
  installed or not
- drop old obsoletes tag
- new version
- spec cleanup

* Sat Jun 09 2012 zezinho <zezinho> 0:1.1.13-2.mga3
+ Revision: 258863
- add a suggests for python-svn, as it does not work on svn repos without it

* Sun Mar 04 2012 supp <supp> 0:1.1.13-1.mga2
+ Revision: 217646
- update to latest version - 1.1.13

* Fri Nov 04 2011 fwang <fwang> 0:1.1.12-1.mga2
+ Revision: 162610
- new version 1.1.12

* Thu May 19 2011 dmorgan <dmorgan> 0:1.1.11-1.mga1
+ Revision: 99736
- Update to version 1.1.11 ( sec fix )
  Remove buildroot
  Remove Mandriva word

* Thu Apr 14 2011 tv <tv> 0:1.1.9-1.mga1
+ Revision: 84871
- new release

* Tue Jan 11 2011 supp <supp> 0:1.1.8-1.mga1
+ Revision: 6530
- clean up archaic macros!
- imported package viewvc


* Tue Jan 11 2011 Tomas Kindl <supp@mageia-devel.com> 0:1.1.8-1.mga1
- import to Mageia

* Fri Sep 10 2010 Funda Wang <fwang@mandriva.org> 0:1.1.7-1mdv2011.0
+ Revision: 577118
- new version 1.1.7

* Tue Mar 30 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.1.5-1mdv2010.1
+ Revision: 528953
- 1.1.5

* Thu Mar 11 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.1.4-1mdv2010.1
+ Revision: 517984
- 1.1.4

* Sun Jan 17 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0:1.1.3-3mdv2010.1
+ Revision: 492703
- use herein document instead of external source for README.mdv
- rely on filetrigger for reloading apache configuration begining with 2010.1, rpm-helper macros otherwise

* Thu Jan 07 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.1.3-2mdv2010.1
+ Revision: 487113
- added mod_python support
- whoops, really fix path to templates
- limit access to the cgi files per default
- more config fixes
- package mod_python files
- fix path to templates

* Wed Dec 30 2009 Frederik Himpe <fhimpe@mandriva.org> 0:1.1.3-1mdv2010.1
+ Revision: 484041
- Update to new version 1.1.3

* Wed Aug 12 2009 Funda Wang <fwang@mandriva.org> 0:1.1.2-1mdv2010.0
+ Revision: 415260
- new version 1.1.2

* Fri Jun 05 2009 Funda Wang <fwang@mandriva.org> 0:1.1.1-1mdv2010.0
+ Revision: 383002
- update tools patch
- New version 1.1.1

* Sun Nov 30 2008 David Walluck <walluck@mandriva.org> 0:1.1.0-0.beta1.1mdv2009.1
+ Revision: 308328
- 1.1.0

* Sat Oct 18 2008 David Walluck <walluck@mandriva.org> 0:1.0.7-1mdv2009.1
+ Revision: 295155
- remove obsolete patches
- 1.0.7

* Thu Sep 18 2008 Frederik Himpe <fhimpe@mandriva.org> 0:1.0.5-5mdv2009.0
+ Revision: 285705
- Add patch from upstream svn fixing a small security problem
  (http://viewvc.tigris.org/issues/show_bug.cgi?id=354)

* Sun Aug 03 2008 Thierry Vignaud <tv@mandriva.org> 0:1.0.5-4mdv2009.0
+ Revision: 261852
- rebuild

* Wed Jul 30 2008 Thierry Vignaud <tv@mandriva.org> 0:1.0.5-3mdv2009.0
+ Revision: 255528
- rebuild

* Tue Mar 04 2008 Frederik Himpe <fhimpe@mandriva.org> 0:1.0.5-1mdv2008.1
+ Revision: 178842
- New upstream bug and security fix release

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Aug 22 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0:1.0.4-3mdv2008.0
+ Revision: 69124
- requires python, for cgi module

* Fri Jun 01 2007 David Walluck <walluck@mandriva.org> 0:1.0.4-2mdv2008.0
+ Revision: 33680
- version explicit Obsoletes
- fix patch specifying config file location
- remove epoch from the build root
- update README.mdv a bit

* Tue Apr 17 2007 David Walluck <walluck@mandriva.org> 0:1.0.4-1mdv2008.0
+ Revision: 14167
- 1.0.4


* Fri Jan 19 2007 Gustavo De Nardin <gustavodn@mandriva.com> 1.0.3-2mdv2007.0
+ Revision: 110542
- Patch from trunk r1504, to speed up directory listing when use_pagesize > 0.

* Thu Oct 19 2006 David Walluck <walluck@mandriva.org> 0:1.0.3-1mdv2007.1
+ Revision: 66090
- 1.0.3
- Import viewvc

* Sat Jul 22 2006 David Walluck <walluck@mandriva.org> 0:1.0.1-1mdv2007.0
- 1.0.1
- fix macros in changelog

* Tue Jun 27 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0:1.0.0-2mdv2007.0
- new webapp macros
- decompress all patches

* Wed May 03 2006 David Walluck <walluck@mandriva.org> 0:1.0.0-1mdk
- 1.0.0
- fix find syntax

* Tue Apr 11 2006 David Walluck <walluck@mandriva.org> 0:1.0-0.20060410.1mdk
- updated snapshot in line with the official 1.0.0-rc1 release on Apr 06

* Wed Mar 29 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0:1.0-0.20060328.1mdk
- updated snapshot (should fix query mode)
- rediff config patch
- make most requires optionals, and document them in README.mdv

* Sun Mar 19 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0:1.0-0.20060123.2mdk
- backport compatible apache configuration file
- require MySQL-python for query.cgi

* Mon Jan 23 2006 David Walluck <walluck@mandriva.org> 0:1.0-0.20060123.1mdk- CVS (20060123)
* Tue Nov 15 2005 Guillaume Rousse <guillomovitch@mandriva.org> 0:1.0-0.20050115.6mdk
- FHS installation:
 - move configuration files to %%{_sysconfdir}/%%{name}
 - move static files to %%{_var}/www/%%{name}
 - move data files to %%{_datadir}/%%{name}
- spec cleanup
- fix URL
- fix python files perms and shellbang

* Sat Jul 30 2005 Nicolas Lécureuil <neoclust@mandriva.org> 1.0-0.20050115.5mdk
- Fix Requires

* Sat Jul 30 2005 Nicolas Lécureuil <neoclust@mandriva.org> 1.0-0.20050115.4mdk
- Fix BuildRequires

* Sun Feb 06 2005 David Walluck <walluck@mandrake.org> 0:1.0-0.20050115.3mdk
- rebuild

* Sat Jan 29 2005 David Walluck <walluck@mandrake.org> 0:1.0-0.20050115.2mdk
- add tools
- patch tools to fix tools/make_database

* Sun Oct 31 2004 David Walluck <walluck@mandrake.org> 0:1.0-0.20050115.1mdk
- 1.0-dev (CVS-20050115)

* Sun Oct 31 2004 David Walluck <walluck@mandrake.org> 0:1.0-0.20041030.1mdk
- 1.0-dev (CVS-20041030)
- fix website docs install
- fix apache icons location
- remove CVS dirs
- don't copy tools
- requires python-svn (needed for svn support)
- doesn't require enscript by default
- doesn't require rcs by default

* Wed Jun 09 2004 Olivier Thauvin <thauvin@aerov.jussieu.fr> 1.0-0.20040223.4mdk
- Requires python itself (cgi.py)

* Tue Feb 24 2004 David Walluck <walluck@linux-mandrake.com> 0:1.0-0.20040223.3mdk
- use existing perl regex instead of patch

* Tue Feb 24 2004 Olivier Thauvin <thauvin@aerov.jussieu.fr> 1.0-0.20040223.2mdk
- %%patch0: uses png icons since http2 don't have gif

* Mon Feb 23 2004 David Walluck <walluck@linux-mandrake.com> 0:1.0-0.20040223.1mdk
- 1.0-dev (CVS-20040223) - svn 1.0 is out now, so why not update this as well
- update my email address in %%changelog

* Sun Feb 01 2004 David Walluck <walluck@linux-mandrake.com> 0:1.0-0.20040201.1mdk
- 1.0-dev (CVS-20040201) with fix for enabling of cvsgraph when not using cvs
- fix path of custom cvsgraph config

